@@ -3,13 +3,15 @@ fritzconnection
 
 library to communicate with the AVM Fritz!Box
 via Soap and TR-064.
+provides also interface for realtime call-monitoring.
 
 for documentation refer:
 https://avm.de/service/schnittstellen/
 https://fritzconnection.readthedocs.io/
 """
 
-__version__ = '1.3.4'
+__version__ = "1.4.2"
 
-# import shortcut
+# import shortcuts
 from .core.fritzconnection import FritzConnection
+from .core.fritzmonitor import FritzMonitor
