@@ -15,7 +15,7 @@ from ..core.exceptions import (
 from .fritzbase import AbstractLibraryBase
 
 
-SERVICE = 'Hosts1'
+SERVICE = "Hosts1"
 
 
 class FritzHosts(AbstractLibraryBase):
@@ -29,15 +29,13 @@ class FritzHosts(AbstractLibraryBase):
     """
 
     def _action(self, actionname, *, arguments=None, **kwargs):
-        return self.fc.call_action(
-            SERVICE, actionname, arguments=arguments, **kwargs
-        )
+        return self.fc.call_action(SERVICE, actionname, arguments=arguments, **kwargs)
 
     @property
     def host_numbers(self):
         """The number of known hosts."""
-        result = self._action('GetHostNumberOfEntries')
-        return result['NewHostNumberOfEntries']
+        result = self._action("GetHostNumberOfEntries")
+        return result["NewHostNumberOfEntries"]
 
     def get_generic_host_entry(self, index):
         """
@@ -45,14 +43,14 @@ class FritzHosts(AbstractLibraryBase):
         registered by the position *index*. Index-positions are
         zero-based.
         """
-        return self._action('GetGenericHostEntry', NewIndex=index)
+        return self._action("GetGenericHostEntry", NewIndex=index)
 
     def get_specific_host_entry(self, mac_address):
         """
         Returns a dictionary with informations about a device addressed
         by the MAC-address.
         """
-        return self._action('GetSpecificHostEntry', NewMACAddress=mac_address)
+        return self._action("GetSpecificHostEntry", NewMACAddress=mac_address)
 
     def get_specific_host_entry_by_ip(self, ip):
         """
@@ -60,7 +58,7 @@ class FritzHosts(AbstractLibraryBase):
         by the ip-address. Provides additional information about
         connection speed and system-updates for AVM devices.
         """
-        return self._action('X_AVM-DE_GetSpecificHostEntryByIP',NewIPAddress=ip)
+        return self._action("X_AVM-DE_GetSpecificHostEntryByIP", NewIPAddress=ip)
 
     def get_host_status(self, mac_address):
         """
@@ -73,14 +71,14 @@ class FritzHosts(AbstractLibraryBase):
             result = self.get_specific_host_entry(mac_address)
         except (FritzArgumentError, FritzLookUpError):
             return None
-        return result['NewActive']
+        return result["NewActive"]
 
     def get_active_hosts(self):
         """
         Returns a list of dicts with information about the active
         devices. The dict-keys are: 'ip', 'name', 'mac', 'status'
         """
-        return [host for host in self.get_hosts_info() if host['status']]
+        return [host for host in self.get_hosts_info() if host["status"]]
 
     def get_hosts_info(self):
         """
@@ -94,11 +92,14 @@ class FritzHosts(AbstractLibraryBase):
             except IndexError:
                 # no more host entries:
                 break
-            result.append({
-                'ip': host['NewIPAddress'],
-                'name': host['NewHostName'],
-                'mac': host['NewMACAddress'],
-                'status': host['NewActive']})
+            result.append(
+                {
+                    "ip": host["NewIPAddress"],
+                    "name": host["NewHostName"],
+                    "mac": host["NewMACAddress"],
+                    "status": host["NewActive"],
+                }
+            )
         return result
 
     def get_mesh_topology(self, raw=False):
@@ -108,9 +109,9 @@ class FritzHosts(AbstractLibraryBase):
         of nodes. If `raw` is `True` the data are returned as text in
         json format. Default is `False`.
         """
-        result = self._action('X_AVM-DE_GetMeshListPath')
-        path = result['NewX_AVM-DE_MeshListPath']
-        url = f'{self.fc.address}:{self.fc.port}{path}'
+        result = self._action("X_AVM-DE_GetMeshListPath")
+        path = result["NewX_AVM-DE_MeshListPath"]
+        url = f"{self.fc.address}:{self.fc.port}{path}"
         with self.fc.session.get(url) as response:
             return response.text if raw else response.json()
 
@@ -120,9 +121,9 @@ class FritzHosts(AbstractLibraryBase):
         device with the given `mac_address` in case of a remote access.
         """
         info = self._action(
-            'X_AVM-DE_GetAutoWakeOnLANByMACAddress', NewMACAddress=mac_address
+            "X_AVM-DE_GetAutoWakeOnLANByMACAddress", NewMACAddress=mac_address
         )
-        return info['NewAutoWOLEnabled']
+        return info["NewAutoWOLEnabled"]
 
     def set_wakeonlan_status(self, mac_address, status=False):
         """
@@ -132,10 +133,10 @@ class FritzHosts(AbstractLibraryBase):
         no return value.
         """
         args = {
-            'NewMACAddress': mac_address,
-            'NewAutoWOLEnabled': status,
+            "NewMACAddress": mac_address,
+            "NewAutoWOLEnabled": status,
         }
-        self._action('X_AVM-DE_SetAutoWakeOnLANByMACAddress', arguments=args)
+        self._action("X_AVM-DE_SetAutoWakeOnLANByMACAddress", arguments=args)
 
     def set_host_name(self, mac_address, name):
         """
@@ -143,10 +144,16 @@ class FritzHosts(AbstractLibraryBase):
         the new `name`.
         """
         args = {
-            'NewMACAddress': mac_address,
-            'NewHostName': name,
+            "NewMACAddress": mac_address,
+            "NewHostName": name,
         }
-        self._action('X_AVM-DE_SetHostNameByMACAddress', arguments=args)
+        self._action("X_AVM-DE_SetHostNameByMACAddress", arguments=args)
+
+    def get_host_name(self, mac_address):
+        """
+        Returns a String with the host_name of the device with the given mac_address
+        """
+        return self.get_specific_host_entry(mac_address)["NewHostName"]
 
     def run_host_update(self, mac_address):
         """
@@ -156,4 +163,4 @@ class FritzHosts(AbstractLibraryBase):
         system update apply, like not turning power off during a system
         update. So run this command with caution.
         """
-        self._action('X_AVM-DE_HostDoUpdate', NewMACAddress=mac_address)
+        self._action("X_AVM-DE_HostDoUpdate", NewMACAddress=mac_address)
